import type { FieldNodeList } from '../models/FieldNodeList';
import type { PagedStudies } from '../models/PagedStudies';
import type { Status } from '../models/Status';
import type { Study } from '../models/Study';
import type { CancelablePromise } from '../core/CancelablePromise';
export declare class StudiesService {
    /**
     * Studies
     * Returns data of studies matching query and filter parameters. The studies are returned page by page.
     * If response contains `nextPageToken`, use its value in `pageToken` to get next page.
     * The last page will not contain `nextPageToken`. A page may have empty `studies` array.
     * Request for each subsequent page **must** have the same parameters as for the first page, except
     * `countTotal`, `pageSize`, and `pageToken` parameters.
     *
     * If neither queries nor filters are set, all studies will be returned.
     * If any query parameter contains only NCT IDs (comma- and/or space-separated), filters are ignored.
     *
     * `filter.*` and `postFilter.*` parameters have same effect as there is no aggregation calculation.
     * Both are available just to simplify applying parameters from search request.
     *
     * Note: When trying JSON format in your browser, do not set too large `pageSize` parameter, if `fields` is
     * unlimited. That may return too much data for the browser to parse and render.
     * @returns PagedStudies OK
     * @throws ApiError
     */
    static listStudies({ format, queryCond, queryTerm, queryLocn, queryTitles, queryIntr, queryOutc, querySpons, queryLead, queryId, queryPatient, filterOverallStatus, filterGeo, filterIds, filterAdvanced, filterSynonyms, postFilterOverallStatus, postFilterGeo, postFilterIds, postFilterAdvanced, postFilterSynonyms, aggFilters, geoDecay, fields, sort, countTotal, pageSize, pageToken, }: {
        /**
         * Must be one of the following:
         * * `csv`- return CSV table with one page of study data; first page will contain header with column names; available fields are listed on [CSV Download](/csv-download) page
         * * `json`- return JSON with one page of study data; every study object is placed in a separate line; `markup` type fields are in [markdown](https://spec.commonmark.org/0.28/) format
         */
        format?: 'csv' | 'json';
        /**
         * "Conditions or disease" query. See "ConditionSearch Area" on [Search Areas](/search-areas#ConditionSearch) for more details.
         */
        queryCond?: string;
        /**
         * "Other terms" query. See "BasicSearch Area" on [Search Areas](/search-areas#BasicSearch) for more details.
         */
        queryTerm?: string;
        /**
         * "Location terms" query. See "LocationSearch Area" on [Search Areas](/search-areas#LocationSearch) for more details.
         */
        queryLocn?: string;
        /**
         * "Title / acronym" query. See "TitleSearch Area" on [Search Areas](/search-areas#TitleSearch) for more details.
         */
        queryTitles?: string;
        /**
         * "Intervention / treatment" query. See "InterventionSearch Area" on [Search Areas](/search-areas#InterventionSearch) for more details.
         */
        queryIntr?: string;
        /**
         * "Outcome measure" query. See "OutcomeSearch Area" on [Search Areas](/search-areas#OutcomeSearch) for more details.
         */
        queryOutc?: string;
        /**
         * "Sponsor / collaborator" query. See "SponsorSearch Area" on [Search Areas](/search-areas#SponsorSearch) for more details.
         */
        querySpons?: string;
        /**
         * Searches in "LeadSponsorName" field. See [Study Data Structure](/study-data-structure#LeadSponsorName) for more details.
         */
        queryLead?: string;
        /**
         * "Study IDs" query. See "IdSearch Area" on [Search Areas](/search-areas#IdSearch) for more details.
         */
        queryId?: string;
        /**
         * See "PatientSearch Area" on [Search Areas](/search-areas#PatientSearch) for more details.
         */
        queryPatient?: string;
        /**
         * Filter by comma- or pipe-separated list of statuses
         */
        filterOverallStatus?: Array<Status>;
        /**
         * Filter by geo-function. Currently only distance function is supported.
         * Format: `distance(latitude,longitude,distance)`
         */
        filterGeo?: string;
        /**
         * Filter by comma- or pipe-separated list of NCT numbers (a.k.a. ClinicalTrials.gov identifiers)
         */
        filterIds?: Array<string>;
        /**
         * Filter by query in [Essie expression syntax](https://classic.clinicaltrials.gov/api/gui/ref/syntax)
         */
        filterAdvanced?: string;
        /**
         * Filter by comma- or pipe-separated list of `area`:`synonym_id` pairs
         */
        filterSynonyms?: Array<string>;
        /**
         * Filter by comma- or pipe-separated list of statuses
         */
        postFilterOverallStatus?: Array<Status>;
        /**
         * Filter by geo-function. Currently only distance function is supported.
         * Format: `distance(latitude,longitude,distance)`
         */
        postFilterGeo?: string;
        /**
         * Filter by comma- or pipe-separated list of NCT numbers (a.k.a. ClinicalTrials.gov identifiers)
         */
        postFilterIds?: Array<string>;
        /**
         * Filter by query in [Essie expression syntax](https://classic.clinicaltrials.gov/api/gui/ref/syntax)
         */
        postFilterAdvanced?: string;
        /**
         * Filter by comma- or pipe-separated list of `area`:`synonym_id` pairs
         */
        postFilterSynonyms?: Array<string>;
        /**
         * Apply aggregation filters, aggregation counts will not be provided.
         * The value is comma- or pipe-separated list of pairs `filter_id`:`space-separated list of option keys` for the checked options.
         */
        aggFilters?: string;
        /**
         * Set proximity factor by distance from `filter.geo` location to the closest [LocationGeoPoint](/study-data-structure#LocationGeoPoint) of a study.
         * Ignored, if `filter.geo` parameter is not set or response contains more than 10,000 studies.
         */
        geoDecay?: string;
        /**
         * If specified, must be non-empty comma- or pipe-separated list of fields to return. If unspecified, all fields will be returned.
         * Order of the fields does not matter.
         *
         * For `csv` format, specify list of columns. The column names are available on [CSV Download](/csv-download).
         *
         * For `json` format, every list item is either area name, piece name, field name, or special name.
         * If a piece or a field is a branch node, all descendant fields will be included.
         * All area names are available on [Search Areas](/search-areas),
         * the piece and field names — on [Data Structure](/study-data-structure) and also can be retrieved at `/studies/metadata` endpoint.
         * There is a special name, `@query`, which expands to all fields queried by search.
         */
        fields?: Array<string>;
        /**
         * comma- or pipe-separated list of sorting options of the studies. The returning studies are not sorted by default for a performance reason.
         * Every list item contains a field/piece name and an optional sort direction (`asc` for ascending or `desc` for descending)
         * after colon character.
         *
         * All piece and field names can be found on [Data Structure](/study-data-structure) and also can be retrieved
         * at `/studies/metadata` endpoint. Currently, only date and numeric fields are allowed for sorting.
         * There is a special "field" `@relevance` to sort by relevance to a search query.
         *
         * Studies missing sort field are always last. Default sort direction:
         * * Date field - `desc`
         * * Numeric field - `asc`
         * * `@relevance` - `desc`
         */
        sort?: Array<string>;
        /**
         * Count total number of studies in all pages and return `totalCount` field with first page, if `true`.
         * For CSV, the result can be found in `x-total-count` response header.
         * The parameter is ignored for the subsequent pages.
         */
        countTotal?: boolean;
        /**
         * Page size is maximum number of studies to return in response. It does not have to be the same for every page.
         * If not specified or set to 0, the default value will be used. It will be coerced down to  1,000, if greater than that.
         */
        pageSize?: number;
        /**
         * Token to get next page. Set it to a `nextPageToken` value returned with the previous page in JSON format.
         * For CSV, it can be found in `x-next-page-token` response header.
         * Do not specify it for first page.
         */
        pageToken?: string;
    }): CancelablePromise<PagedStudies>;
    /**
     * Single Study
     * Returns data of a single study.
     * @returns Study OK
     * @throws ApiError
     */
    static fetchStudy({ nctId, format, fields, }: {
        /**
         * NCT Number of a study
         */
        nctId: string;
        /**
         * Must be one of the following:
         * * `csv`- return CSV table; available fields are listed on [CSV Download](/csv-download)
         * * `json`- return JSON object; field values of type `markup` are in [markdown](https://spec.commonmark.org/0.28/) format
         * * `json.zip`- put JSON object into a .json file and download it as zip archive; field values of type `markup` are in [markdown](https://spec.commonmark.org/0.28/) format
         * * `fhir.json` - return FHIR JSON; fields are not customizable
         */
        format?: 'csv' | 'json' | 'json.zip' | 'fhir.json';
        /**
         * If specified, must be non-empty comma- or pipe-separated list of fields to return. If unspecified, all fields will be returned.
         * Order of the fields does not matter.
         *
         * For `csv` format, specify list of columns. The column names are available on [CSV Download](/csv-download).
         *
         * For `json` and `json.zip` formats, every list item is either area name, piece name, or field name.
         * If a piece or a field is a branch node, all descendant fields will be included.
         * All area names are available on [Search Areas](/search-areas),
         * the piece and field names - on [Data Structure](/study-data-structure) and also can be retrieved at `/studies/metadata` endpoint.
         *
         * For `fhir.json` format, all available fields are returned and this parameter must be unspecified.
         */
        fields?: Array<string>;
    }): CancelablePromise<Study>;
    /**
     * Data Model Fields
     * Returns study data model fields.
     * @returns FieldNodeList OK
     * @throws ApiError
     */
    static studiesMetadata({ includeIndexedOnly, includeHistoricOnly, }: {
        /**
         * Include indexed-only fields, if `true`
         */
        includeIndexedOnly?: boolean;
        /**
         * Include fields available only in historic data, if `true`
         */
        includeHistoricOnly?: boolean;
    }): CancelablePromise<FieldNodeList>;
}
