"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StudiesService = void 0;
const OpenAPI_1 = require("../core/OpenAPI");
const request_1 = require("../core/request");
class StudiesService {
    /**
     * Studies
     * Returns data of studies matching query and filter parameters. The studies are returned page by page.
     * If response contains `nextPageToken`, use its value in `pageToken` to get next page.
     * The last page will not contain `nextPageToken`. A page may have empty `studies` array.
     * Request for each subsequent page **must** have the same parameters as for the first page, except
     * `countTotal`, `pageSize`, and `pageToken` parameters.
     *
     * If neither queries nor filters are set, all studies will be returned.
     * If any query parameter contains only NCT IDs (comma- and/or space-separated), filters are ignored.
     *
     * `filter.*` and `postFilter.*` parameters have same effect as there is no aggregation calculation.
     * Both are available just to simplify applying parameters from search request.
     *
     * Note: When trying JSON format in your browser, do not set too large `pageSize` parameter, if `fields` is
     * unlimited. That may return too much data for the browser to parse and render.
     * @returns PagedStudies OK
     * @throws ApiError
     */
    static listStudies({ format = 'json', queryCond, queryTerm, queryLocn, queryTitles, queryIntr, queryOutc, querySpons, queryLead, queryId, queryPatient, filterOverallStatus, filterGeo, filterIds, filterAdvanced, filterSynonyms, postFilterOverallStatus, postFilterGeo, postFilterIds, postFilterAdvanced, postFilterSynonyms, aggFilters, geoDecay = 'func:exp,scale:300mi,offset:0mi,decay:0.5', fields, sort, countTotal = false, pageSize = 10, pageToken, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/studies',
            query: {
                'format': format,
                'query.cond': queryCond,
                'query.term': queryTerm,
                'query.locn': queryLocn,
                'query.titles': queryTitles,
                'query.intr': queryIntr,
                'query.outc': queryOutc,
                'query.spons': querySpons,
                'query.lead': queryLead,
                'query.id': queryId,
                'query.patient': queryPatient,
                'filter.overallStatus': filterOverallStatus,
                'filter.geo': filterGeo,
                'filter.ids': filterIds,
                'filter.advanced': filterAdvanced,
                'filter.synonyms': filterSynonyms,
                'postFilter.overallStatus': postFilterOverallStatus,
                'postFilter.geo': postFilterGeo,
                'postFilter.ids': postFilterIds,
                'postFilter.advanced': postFilterAdvanced,
                'postFilter.synonyms': postFilterSynonyms,
                'aggFilters': aggFilters,
                'geoDecay': geoDecay,
                'fields': fields,
                'sort': sort,
                'countTotal': countTotal,
                'pageSize': pageSize,
                'pageToken': pageToken,
            },
            errors: {
                400: `Bad request`,
            },
        });
    }
    /**
     * Single Study
     * Returns data of a single study.
     * @returns Study OK
     * @throws ApiError
     */
    static fetchStudy({ nctId, format = 'json', fields, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/studies/{nctId}',
            path: {
                'nctId': nctId,
            },
            query: {
                'format': format,
                'fields': fields,
            },
            errors: {
                400: `Bad request`,
                404: `Not found`,
            },
        });
    }
    /**
     * Data Model Fields
     * Returns study data model fields.
     * @returns FieldNodeList OK
     * @throws ApiError
     */
    static studiesMetadata({ includeIndexedOnly = false, includeHistoricOnly = false, }) {
        return (0, request_1.request)(OpenAPI_1.OpenAPI, {
            method: 'GET',
            url: '/studies/metadata',
            query: {
                'includeIndexedOnly': includeIndexedOnly,
                'includeHistoricOnly': includeHistoricOnly,
            },
            errors: {
                400: `Bad request`,
            },
        });
    }
}
exports.StudiesService = StudiesService;
